pub enum DomainControllerRequest {
ListDomains {
responder: DomainControllerListDomainsResponder,
},
GetMaxFrequency {
domain_id: u64,
responder: DomainControllerGetMaxFrequencyResponder,
},
SetMaxFrequency {
domain_id: u64,
frequency_index: u64,
responder: DomainControllerSetMaxFrequencyResponder,
},
ClearMaxFrequency {
domain_id: u64,
responder: DomainControllerClearMaxFrequencyResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: DomainControllerControlHandle,
method_type: MethodType,
},
}Variants
ListDomains
Lists info about each domain managed by the server.
The server is guaranteed to fill all fields within DomainInfo unless
the field is explicitly marked as “Optional”.
Fields
responder: DomainControllerListDomainsResponderGetMaxFrequency
Gets the index of the max frequency the CPU can run at.
max_frequency_index corresponds to the index of a frequency within
this domain’s available_frequencies_hz list retrieved via
[ListDomains].
If SetMaxFrequency has never been called, this will return the index that corresponds to the highest available frequency for this domain.
If domain_id is invalid, INVALID_ARGUMENTS is returned.
SetMaxFrequency
Sets the max frequency the CPU can run at.
frequency_index must correspond to the index of a frequency within
this domain’s available_frequencies_hz list retrieved via
[ListDomains].
On products with Runtime Processor Power Management (RPPM), the CPU may briefly exceed max frequency if power limits allow.
If domain_id is invalid, INVALID_ARGUMENTS is returned.
If frequency_index is invalid, INVALID_ARGUMENTS is returned.
ClearMaxFrequency
Clears the max frequency limit the CPU can run at.
If domain_id is invalid, INVALID_ARGUMENTS is returned.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
control_handle: DomainControllerControlHandlemethod_type: MethodTypeImplementations
Sourceimpl DomainControllerRequest
impl DomainControllerRequest
pub fn into_list_domains(self) -> Option<DomainControllerListDomainsResponder>
pub fn into_get_max_frequency( self, ) -> Option<(u64, DomainControllerGetMaxFrequencyResponder)>
pub fn into_set_max_frequency( self, ) -> Option<(u64, u64, DomainControllerSetMaxFrequencyResponder)>
pub fn into_clear_max_frequency( self, ) -> Option<(u64, DomainControllerClearMaxFrequencyResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL