#[repr(C)]pub struct DomainControllerClearMaxFrequencyRequest {
pub domain_id: u64,
}Fields
domain_id: u64Trait Implementations
Sourceimpl Clone for DomainControllerClearMaxFrequencyRequest
impl Clone for DomainControllerClearMaxFrequencyRequest
Sourcefn clone(&self) -> DomainControllerClearMaxFrequencyRequest
fn clone(&self) -> DomainControllerClearMaxFrequencyRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<DomainControllerClearMaxFrequencyRequest, D> for DomainControllerClearMaxFrequencyRequestwhere
D: ResourceDialect,
impl<D> Decode<DomainControllerClearMaxFrequencyRequest, D> for DomainControllerClearMaxFrequencyRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> DomainControllerClearMaxFrequencyRequest
fn new_empty() -> DomainControllerClearMaxFrequencyRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<DomainControllerClearMaxFrequencyRequest, D> for &DomainControllerClearMaxFrequencyRequestwhere
D: ResourceDialect,
impl<D> Encode<DomainControllerClearMaxFrequencyRequest, D> for &DomainControllerClearMaxFrequencyRequestwhere
D: ResourceDialect,
Sourceimpl Ord for DomainControllerClearMaxFrequencyRequest
impl Ord for DomainControllerClearMaxFrequencyRequest
Sourcefn cmp(&self, other: &DomainControllerClearMaxFrequencyRequest) -> Ordering
fn cmp(&self, other: &DomainControllerClearMaxFrequencyRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DomainControllerClearMaxFrequencyRequest
impl PartialEq for DomainControllerClearMaxFrequencyRequest
Sourcefn eq(&self, other: &DomainControllerClearMaxFrequencyRequest) -> bool
fn eq(&self, other: &DomainControllerClearMaxFrequencyRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DomainControllerClearMaxFrequencyRequest
impl PartialOrd for DomainControllerClearMaxFrequencyRequest
Sourceimpl TypeMarker for DomainControllerClearMaxFrequencyRequest
impl TypeMarker for DomainControllerClearMaxFrequencyRequest
Sourcetype Owned = DomainControllerClearMaxFrequencyRequest
type Owned = DomainControllerClearMaxFrequencyRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DomainControllerClearMaxFrequencyRequest
impl ValueTypeMarker for DomainControllerClearMaxFrequencyRequest
Sourcetype Borrowed<'a> = &'a DomainControllerClearMaxFrequencyRequest
type Borrowed<'a> = &'a DomainControllerClearMaxFrequencyRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<DomainControllerClearMaxFrequencyRequest as TypeMarker>::Owned,
) -> <DomainControllerClearMaxFrequencyRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<DomainControllerClearMaxFrequencyRequest as TypeMarker>::Owned, ) -> <DomainControllerClearMaxFrequencyRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Copy for DomainControllerClearMaxFrequencyRequest
impl Eq for DomainControllerClearMaxFrequencyRequest
impl Persistable for DomainControllerClearMaxFrequencyRequest
impl StructuralPartialEq for DomainControllerClearMaxFrequencyRequest