pub struct DomainControllerClearMaxFrequencyResponder { /* private fields */ }Implementations
Sourceimpl DomainControllerClearMaxFrequencyResponder
impl DomainControllerClearMaxFrequencyResponder
Sourcepub fn send(
self,
result: Result<(), ClearMaxFrequencyError>,
) -> Result<(), Error>
pub fn send( self, result: Result<(), ClearMaxFrequencyError>, ) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
result: Result<(), ClearMaxFrequencyError>,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, result: Result<(), ClearMaxFrequencyError>, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.