pub struct DomainControllerGetMaxFrequencyResponder { /* private fields */ }Implementations
Sourceimpl DomainControllerGetMaxFrequencyResponder
impl DomainControllerGetMaxFrequencyResponder
Sourcepub fn send(
self,
result: Result<u64, GetMaxFrequencyError>,
) -> Result<(), Error>
pub fn send( self, result: Result<u64, GetMaxFrequencyError>, ) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
result: Result<u64, GetMaxFrequencyError>,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, result: Result<u64, GetMaxFrequencyError>, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.