pub struct DomainControllerMarker;Trait Implementations
Sourceimpl Clone for DomainControllerMarker
impl Clone for DomainControllerMarker
Sourcefn clone(&self) -> DomainControllerMarker
fn clone(&self) -> DomainControllerMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DomainControllerMarker
impl Debug for DomainControllerMarker
Sourceimpl DiscoverableProtocolMarker for DomainControllerMarker
impl DiscoverableProtocolMarker for DomainControllerMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
Sourceimpl Hash for DomainControllerMarker
impl Hash for DomainControllerMarker
Sourceimpl Ord for DomainControllerMarker
impl Ord for DomainControllerMarker
Sourcefn cmp(&self, other: &DomainControllerMarker) -> Ordering
fn cmp(&self, other: &DomainControllerMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DomainControllerMarker
impl PartialEq for DomainControllerMarker
Sourceimpl PartialOrd for DomainControllerMarker
impl PartialOrd for DomainControllerMarker
Sourceimpl ProtocolMarker for DomainControllerMarker
impl ProtocolMarker for DomainControllerMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.power.cpu.DomainController"
const DEBUG_NAME: &'static str = "fuchsia.power.cpu.DomainController"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = DomainControllerProxy
type Proxy = DomainControllerProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = DomainControllerRequestStream
type RequestStream = DomainControllerRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = DomainControllerSynchronousProxy
type SynchronousProxy = DomainControllerSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for DomainControllerMarker
impl Eq for DomainControllerMarker
impl StructuralPartialEq for DomainControllerMarker