pub struct DomainControllerSetMaxFrequencyResponder { /* private fields */ }Implementations
Sourceimpl DomainControllerSetMaxFrequencyResponder
impl DomainControllerSetMaxFrequencyResponder
Sourcepub fn send(self, result: Result<(), SetMaxFrequencyError>) -> Result<(), Error>
pub fn send(self, result: Result<(), SetMaxFrequencyError>) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
result: Result<(), SetMaxFrequencyError>,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, result: Result<(), SetMaxFrequencyError>, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.