DomainControllerSynchronousProxy

Struct DomainControllerSynchronousProxy 

pub struct DomainControllerSynchronousProxy { /* private fields */ }

Implementations

Source

impl DomainControllerSynchronousProxy

pub fn new(channel: Channel) -> Self

pub fn into_channel(self) -> Channel

pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<DomainControllerEvent, Error>

Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.

pub fn list_domains( &self, ___deadline: MonotonicInstant, ) -> Result<Vec<DomainInfo>, Error>

Lists info about each domain managed by the server.

The server is guaranteed to fill all fields within DomainInfo unless the field is explicitly marked as “Optional”.

pub fn get_max_frequency( &self, domain_id: u64, ___deadline: MonotonicInstant, ) -> Result<DomainControllerGetMaxFrequencyResult, Error>

Gets the index of the max frequency the CPU can run at.

max_frequency_index corresponds to the index of a frequency within this domain’s available_frequencies_hz list retrieved via [ListDomains].

If SetMaxFrequency has never been called, this will return the index that corresponds to the highest available frequency for this domain.

If domain_id is invalid, INVALID_ARGUMENTS is returned.

pub fn set_max_frequency( &self, domain_id: u64, frequency_index: u64, ___deadline: MonotonicInstant, ) -> Result<DomainControllerSetMaxFrequencyResult, Error>

Sets the max frequency the CPU can run at.

frequency_index must correspond to the index of a frequency within this domain’s available_frequencies_hz list retrieved via [ListDomains].

On products with Runtime Processor Power Management (RPPM), the CPU may briefly exceed max frequency if power limits allow.

If domain_id is invalid, INVALID_ARGUMENTS is returned. If frequency_index is invalid, INVALID_ARGUMENTS is returned.

pub fn clear_max_frequency( &self, domain_id: u64, ___deadline: MonotonicInstant, ) -> Result<DomainControllerClearMaxFrequencyResult, Error>

Clears the max frequency limit the CPU can run at.

If domain_id is invalid, INVALID_ARGUMENTS is returned.