pub struct DomainInfo {
pub id: Option<u64>,
pub core_ids: Option<Vec<u64>>,
pub available_frequencies_hz: Option<Vec<u64>>,
pub name: Option<String>,
/* private fields */
}Fields
id: Option<u64>core_ids: Option<Vec<u64>>available_frequencies_hz: Option<Vec<u64>>name: Option<String>Trait Implementations
Sourceimpl Clone for DomainInfo
impl Clone for DomainInfo
Sourcefn clone(&self) -> DomainInfo
fn clone(&self) -> DomainInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DomainInfo
impl Debug for DomainInfo
Sourceimpl<D> Decode<DomainInfo, D> for DomainInfowhere
D: ResourceDialect,
impl<D> Decode<DomainInfo, D> for DomainInfowhere
D: ResourceDialect,
Sourcefn new_empty() -> DomainInfo
fn new_empty() -> DomainInfo
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for DomainInfo
impl Default for DomainInfo
Sourcefn default() -> DomainInfo
fn default() -> DomainInfo
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<DomainInfo, D> for &DomainInfowhere
D: ResourceDialect,
impl<D> Encode<DomainInfo, D> for &DomainInfowhere
D: ResourceDialect,
Sourceimpl PartialEq for DomainInfo
impl PartialEq for DomainInfo
Sourceimpl TypeMarker for DomainInfo
impl TypeMarker for DomainInfo
Sourcetype Owned = DomainInfo
type Owned = DomainInfo
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DomainInfo
impl ValueTypeMarker for DomainInfo
Sourcetype Borrowed<'a> = &'a DomainInfo
type Borrowed<'a> = &'a DomainInfo
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<DomainInfo as TypeMarker>::Owned,
) -> <DomainInfo as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<DomainInfo as TypeMarker>::Owned, ) -> <DomainInfo as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for DomainInfo
impl StructuralPartialEq for DomainInfo