pub struct DomainControllerProxy { /* private fields */ }Implementations
Sourceimpl DomainControllerProxy
impl DomainControllerProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.power.cpu/DomainController.
Sourcepub fn take_event_stream(&self) -> DomainControllerEventStream
pub fn take_event_stream(&self) -> DomainControllerEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn list_domains(
&self,
) -> QueryResponseFut<Vec<DomainInfo>, DefaultFuchsiaResourceDialect>
pub fn list_domains( &self, ) -> QueryResponseFut<Vec<DomainInfo>, DefaultFuchsiaResourceDialect>
Lists info about each domain managed by the server.
The server is guaranteed to fill all fields within DomainInfo unless
the field is explicitly marked as “Optional”.
Sourcepub fn get_max_frequency(
&self,
domain_id: u64,
) -> QueryResponseFut<DomainControllerGetMaxFrequencyResult, DefaultFuchsiaResourceDialect>
pub fn get_max_frequency( &self, domain_id: u64, ) -> QueryResponseFut<DomainControllerGetMaxFrequencyResult, DefaultFuchsiaResourceDialect>
Gets the index of the max frequency the CPU can run at.
max_frequency_index corresponds to the index of a frequency within
this domain’s available_frequencies_hz list retrieved via
[ListDomains].
If SetMaxFrequency has never been called, this will return the index that corresponds to the highest available frequency for this domain.
If domain_id is invalid, INVALID_ARGUMENTS is returned.
Sourcepub fn set_max_frequency(
&self,
domain_id: u64,
frequency_index: u64,
) -> QueryResponseFut<DomainControllerSetMaxFrequencyResult, DefaultFuchsiaResourceDialect>
pub fn set_max_frequency( &self, domain_id: u64, frequency_index: u64, ) -> QueryResponseFut<DomainControllerSetMaxFrequencyResult, DefaultFuchsiaResourceDialect>
Sets the max frequency the CPU can run at.
frequency_index must correspond to the index of a frequency within
this domain’s available_frequencies_hz list retrieved via
[ListDomains].
On products with Runtime Processor Power Management (RPPM), the CPU may briefly exceed max frequency if power limits allow.
If domain_id is invalid, INVALID_ARGUMENTS is returned.
If frequency_index is invalid, INVALID_ARGUMENTS is returned.
Sourcepub fn clear_max_frequency(
&self,
domain_id: u64,
) -> QueryResponseFut<DomainControllerClearMaxFrequencyResult, DefaultFuchsiaResourceDialect>
pub fn clear_max_frequency( &self, domain_id: u64, ) -> QueryResponseFut<DomainControllerClearMaxFrequencyResult, DefaultFuchsiaResourceDialect>
Clears the max frequency limit the CPU can run at.
If domain_id is invalid, INVALID_ARGUMENTS is returned.